version_core

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 18, 2022 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Compare

func Compare(blocks []Block) string

Compare is to check the different version core blocks The function returns a string with the information like `major update`

Types

type Block

type Block struct {
	Name    string
	Number1 int
	Number2 int
}

Block is to save the version core blocks as a pair

type Core added in v1.1.0

type Core struct {
	Major int
	Minor int
	Patch int
}

Core is to save the version core as major, minor and patch

func Split

func Split(version string) (Core, error)

Split is to check the given version as a string The function checks the string with regex And split the value in major, minor and patch

Jump to