The highest tagged major version is
v5.
package
Version:
v1.3.0
Opens a new window with list of versions in this module.
Published: Aug 18, 2022
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Compare is to check the different version core blocks
The function returns a string with the information like `major update`
Block is to save the version core blocks as a pair
type Core struct {
Major int
Minor int
Patch int
}
Core is to save the version core as major, minor and patch
Split is to check the given version as a string
The function checks the string with regex
And split the value in major, minor and patch
Source Files
¶
Click to show internal directories.
Click to hide internal directories.